@@ -364,6 +364,8 @@ sub instanciatePlugin {
     my $name = shift;
 
     my $user = shift;
+    my $args = shift;
+
     my $prototype = $self->cfgHash->{PLUGIN}{prototype}{$name};
 
     # clean the name
@@ -376,6 +378,7 @@ sub instanciatePlugin {
         user => $user,
         name => $prototype->name,
         config => $prototype->config,
+        args => $args,
         app => $self->app,
     );
     die mkerror(39944,"No permission to access $name")
